@@ -4,6 +4,8 @@ package api
 type AccessToken struct {
 	// The token value, typically a 40-character random string.
 	Token string
+	// The refresh token value, associated with the access token.
+	RefreshToken string
 	// The token type, e.g. "bearer".
 	Type string
 	// Space-separated list of OAuth scopes that this token grants.
@@ -14,9 +16,10 @@ type AccessToken struct {
 func (f FormResponse) AccessToken() (*AccessToken, error) {
 	if accessToken := f.Get("access_token"); accessToken != "" {
 		return &AccessToken{
-			Token: accessToken,
-			Type:  f.Get("token_type"),
-			Scope: f.Get("scope"),
+			Token:        accessToken,
+			RefreshToken: f.Get("refresh_token"),
+			Type:         f.Get("token_type"),
+			Scope:        f.Get("scope"),
 		}, nil
 	}
 
