@@ -1,20 +1,23 @@
-package device
+package device_test
 
 import (
+	"context"
 	"fmt"
 	"net/http"
 	"os"
+
+	"github.com/cli/oauth/device"
 )
 
 // This demonstrates how to perform OAuth Device Authorization Flow for GitHub.com.
 // After RequestCode successfully completes, the client app should prompt the user to copy
 // the UserCode and to open VerificationURI in their web browser to enter the code.
-func Example() {
+func ExampleRequestCode() {
 	clientID := os.Getenv("OAUTH_CLIENT_ID")
 	scopes := []string{"repo", "read:org"}
 	httpClient := http.DefaultClient
 
-	code, err := RequestCode(httpClient, "https://github.com/login/device/code", clientID, scopes)
+	code, err := device.RequestCode(httpClient, "https://github.com/login/device/code", clientID, scopes)
 	if err != nil {
 		panic(err)
 	}
@@ -22,7 +25,10 @@ func Example() {
 	fmt.Printf("Copy code: %s\n", code.UserCode)
 	fmt.Printf("then open: %s\n", code.VerificationURI)
 
-	accessToken, err := PollToken(httpClient, "https://github.com/login/oauth/access_token", clientID, code)
+	accessToken, err := device.Wait(context.TODO(), httpClient, "https://github.com/login/oauth/access_token", device.WaitOptions{
+		ClientID:   clientID,
+		DeviceCode: code,
+	})
 	if err != nil {
 		panic(err)
 	}
